python-opcua-webclient
===============
A OPCUA web client, implemented by Python.

Install
===============

```bash
 pip install opcua-webclient
```

Use
===============
run command:
```
 opcua-webclient
```
on Windows use:
```
 opcua-webclient
```
if can't find opcua-webclient command, try:
```
 python -m opcuawebclient
```
then use web browser(recommend Chrome or Firefox) open http://127.0.0.1:8000, enjoy it.

use youself bind address:

```
opcua-webclient 127.0.0.1:8080
```